@@ -1,5 +1,6 @@
 vblpcmKL<-function(x)
   {
+  model<-x$model
   P_n<-x$P_n
   P_e<-x$P_e
   d<-x$d
@@ -16,7 +17,6 @@ vblpcmKL<-function(x)
   EnonE<-x$EnonE
   diam<-x$diam
   hopslist<-x$hopslist
-  XX_n<-x$XX_n
   XX_e<-x$XX_e
   V_xi_n<-x$V_xi_n
   V_xi_e<-x$V_xi_e
@@ -38,26 +38,28 @@ vblpcmKL<-function(x)
   inv_sigma02<-x$inv_sigma02
   NC=x$NC
   KL=0
-  total_KL<-function(P_n, P_e, D, N, NE, NnonE, NM, G, Y, E, nonE, M, numedges, EnonE, diam, hopslist, XX_n, XX_e, 
+  imodel=switch(model, plain=0, rsender=1, rreceiver=2, rsocial=3)
+  total_KL<-function(imodel, P_n, P_e, D, N, NE, NnonE, NM, G, Y, E, nonE, M, numedges, EnonE, diam, hopslist, XX_e, 
                      V_xi_n, V_xi_e, V_psi2_n, V_psi2_e, V_z, V_sigma2, V_eta, V_lambda, V_omega2, V_nu, V_alpha, xi, 
                      psi2, sigma02, omega2, nu, alpha, inv_sigma02, NC, KL) 
   		     {
-                     ans<-.C("KL_total", NAOK=TRUE, P_n=as.integer(P_n),P_e=as.integer(P_e),D=as.integer(d), N=as.integer(N), 
+                     ans<-.C("KL_total", NAOK=TRUE, 
+                     imodel=as.integer(imodel), P_n=as.integer(P_n),P_e=as.integer(P_e),D=as.integer(d), N=as.integer(N), 
   		     NE=as.integer(NE), NnonE=as.integer(NnonE), NM=as.integer(NM),
                      G=as.integer(G), Y=as.numeric(t(Y)), E=as.integer(t(E)), nonE=as.integer(t(nonE)), M=as.integer(t(M)),
                      numedges=as.integer(t(numedges)), EnonE=as.integer(t(EnonE)),
-		     diam=as.integer(diam), hopslist=as.integer(t(hopslist)), XX_n=as.double(t(XX_n)),
+		     diam=as.integer(diam), hopslist=as.integer(t(hopslist)), 
                      XX_e=as.double(t(XX_e)), V_xi_n=as.double(V_xi_n), V_xi_e=as.double(V_xi_e), 
                      V_psi2_n=as.double(V_psi2_n), V_psi2_e=as.double(V_psi2_e), V_z=as.double(t(V_z)),
                      V_sigma2=as.double(V_sigma2), V_eta=as.double(t(V_eta)), V_lambda=as.double(t(V_lambda)),
                      V_omega2=as.double(V_omega2), V_nu=as.double(V_nu), V_alpha=as.double(V_alpha),
                      xi=as.double(xi), psi2=as.double(psi2), sigma02=as.double(sigma02),
                      omega2=as.double(omega2), nu=as.double(nu), alpha=as.double(alpha),
-                     inv_sigma02=as.double(inv_sigma02), dists=as.double(t(as.matrix(dist(V_z)))),
+                     inv_sigma02=as.double(inv_sigma02), 
   		     NC=as.integer(NC), KL=as.double(KL), PACKAGE="VBLPCM")
                      return(ans)
                      }
-  final_KL<-total_KL(P_n, P_e, d, N, NE, NnonE, NM, G, Y, E, nonE, M, numedges, EnonE, diam, hopslist, XX_n, XX_e, V_xi_n, V_xi_e, 
+  final_KL<-total_KL(imodel, P_n, P_e, d, N, NE, NnonE, NM, G, Y, E, nonE, M, numedges, EnonE, diam, hopslist, XX_e, V_xi_n, V_xi_e, 
                      V_psi2_n, V_psi2_e, V_z, V_sigma2, V_eta, V_lambda, V_omega2, V_nu, V_alpha, xi, psi2, sigma02, omega2, nu, alpha,
   		     inv_sigma02, NC, KL)
   cat("KL distance to true posterior is ", final_KL$KL, "+ constant \n")
